@@ -39,6 +39,8 @@ static void wp_props_load_wallpaper (gchar * key,
 				     GnomeWPItem * item,
 				     GnomeWPCapplet * capplet);
 
+static void gnome_wp_set_sensitivities (GnomeWPCapplet* capplet);
+
 static void wp_properties_error_dialog (GtkWindow * parent, char const * msg,
 					GError * err) {
   if (err != NULL) {
@@ -93,9 +95,6 @@ static GnomeWPItem * gnome_wp_add_image (GnomeWPCapplet * capplet,
 					 const gchar * filename) {
   GnomeWPItem * item;
 
-  if (!g_utf8_validate (filename, -1, NULL))
-    return NULL;
-
   item = g_hash_table_lookup (capplet->wphash, filename);
   if (item != NULL) {
     if (item->deleted) {
@@ -260,7 +259,7 @@ static void gnome_wp_option_menu_set (GnomeWPCapplet * capplet,
     } else if (!strcmp (value, "scaled")) {
       gtk_option_menu_set_history (GTK_OPTION_MENU (capplet->wp_opts),
 				   GNOME_WP_SCALE_TYPE_SCALED);
-    } else {
+    } else if (strcmp (value, "none") != 0) {
       gtk_option_menu_set_history (GTK_OPTION_MENU (capplet->wp_opts),
 				   GNOME_WP_SCALE_TYPE_TILED);
     }
@@ -284,14 +283,20 @@ static gboolean gnome_wp_props_wp_set (GnomeWPCapplet * capplet) {
 
     cs = gconf_change_set_new ();
 
+    gnome_wp_set_sensitivities (capplet);
+
     if (!strcmp (item->filename, "(none)")) {
       gconf_change_set_set_string (cs, WP_OPTIONS_KEY, "none");
-      gtk_widget_set_sensitive (capplet->wp_opts, FALSE);
-      gtk_widget_set_sensitive (capplet->rm_button, FALSE);
     } else {
-      gtk_widget_set_sensitive (capplet->wp_opts, TRUE);
-      gtk_widget_set_sensitive (capplet->rm_button, TRUE);
-      gconf_change_set_set_string (cs, WP_FILE_KEY, item->filename);
+      gchar * uri;
+
+      if (g_utf8_validate (item->filename, -1, NULL))
+	uri = g_strdup (item->filename);
+      else
+	uri = g_filename_to_utf8 (item->filename, -1, NULL, NULL, NULL);
+      gconf_change_set_set_string (cs, WP_FILE_KEY, uri);
+      g_free (uri);
+
       gconf_change_set_set_string (cs, WP_OPTIONS_KEY, item->options);
       gnome_wp_option_menu_set (capplet, item->options, FALSE);
     }
@@ -306,14 +311,8 @@ static gboolean gnome_wp_props_wp_set (GnomeWPCapplet * capplet) {
 
     gconf_change_set_unref (cs);
 
-    gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (capplet->pc_picker),
-				item->pcolor->red,
-				item->pcolor->green,
-				item->pcolor->blue, 65535);
-    gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (capplet->sc_picker),
-				item->scolor->red,
-				item->scolor->green,
-				item->scolor->blue, 65535);
+    gtk_color_button_set_color (GTK_COLOR_BUTTON (capplet->pc_picker), item->pcolor);
+    gtk_color_button_set_color (GTK_COLOR_BUTTON (capplet->sc_picker), item->scolor);
 
     g_free (wpfile);
 
@@ -393,7 +392,7 @@ static void wallpaper_properties_clicked (GtkWidget * dialog,
   }
 }
 
-static void gnome_wp_scale_type_changed (GtkMenuShell * shell,
+static void gnome_wp_scale_type_changed (GtkOptionMenu * option_menu,
 					 GnomeWPCapplet * capplet) {
   GnomeWPItem * item = NULL;
   GdkPixbuf * pixbuf;
@@ -439,7 +438,7 @@ static void gnome_wp_scale_type_changed (GtkMenuShell * shell,
 			   item->options, NULL);
 }
 
-static void gnome_wp_shade_type_changed (GtkMenuShell * shell,
+static void gnome_wp_shade_type_changed (GtkOptionMenu * option_menu,
 					 GnomeWPCapplet * capplet) {
   GnomeWPItem * item = NULL;
   GtkTreeIter iter;
@@ -509,20 +508,18 @@ static void gnome_wp_color_changed (GnomeWPCapplet * capplet,
   }
 
   g_free (item->pri_color);
-  gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (capplet->pc_picker),
-			      &item->pcolor->red,
-			      &item->pcolor->green,
-			      &item->pcolor->blue, NULL);
+
+  gtk_color_button_get_color (GTK_COLOR_BUTTON (capplet->pc_picker), item->pcolor);
+
   item->pri_color = g_strdup_printf ("#%02X%02X%02X",
 				     item->pcolor->red >> 8,
 				     item->pcolor->green >> 8,
 				     item->pcolor->blue >> 8);
 
   g_free (item->sec_color);
-  gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (capplet->sc_picker),
-			      &item->scolor->red,
-			      &item->scolor->green,
-			      &item->scolor->blue, NULL);
+
+  gtk_color_button_get_color (GTK_COLOR_BUTTON (capplet->sc_picker), item->scolor);
+
   item->sec_color = g_strdup_printf ("#%02X%02X%02X",
 				     item->scolor->red >> 8,
 				     item->scolor->green >> 8,
@@ -553,7 +550,6 @@ static void gnome_wp_color_changed (GnomeWPCapplet * capplet,
 }
 
 static void gnome_wp_scolor_changed (GtkWidget * widget,
-				     guint r, guint g, guint b, guint a,
 				     GnomeWPCapplet * capplet) {
   gnome_wp_color_changed (capplet, TRUE);
 }
@@ -591,7 +587,7 @@ static void gnome_wp_remove_wallpaper (GtkWidget * widget,
 
 static gboolean gnome_wp_load_stuffs (void * data) {
   GnomeWPCapplet * capplet = (GnomeWPCapplet *) data;
-  gchar * imagepath, * style;
+  gchar * imagepath, * style, * uri;
   GnomeWPItem * item;
 
   style = gconf_client_get_string (capplet->client,
@@ -604,9 +600,15 @@ static gboolean gnome_wp_load_stuffs (void * data) {
 
   gdk_window_set_cursor (capplet->window->window, NULL);
   
-  imagepath = gconf_client_get_string (capplet->client,
-				       WP_FILE_KEY,
-				       NULL);
+  uri = gconf_client_get_string (capplet->client,
+				 WP_FILE_KEY,
+				 NULL);
+
+  if (g_utf8_validate (uri, -1, NULL) && g_file_test (uri, G_FILE_TEST_EXISTS))
+    imagepath = g_strdup (uri);
+  else
+    imagepath = g_filename_from_utf8 (uri, -1, NULL, NULL, NULL);
+  g_free (uri);
 
   item = g_hash_table_lookup (capplet->wphash, imagepath);
   if (item != NULL && strcmp (style, "none") != 0) {
@@ -620,14 +622,9 @@ static gboolean gnome_wp_load_stuffs (void * data) {
     gnome_wp_option_menu_set (capplet, item->options, FALSE);
     gnome_wp_option_menu_set (capplet, item->shade_type, TRUE);
 
-    gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (capplet->pc_picker),
-				item->pcolor->red,
-				item->pcolor->green,
-				item->pcolor->blue, 65535);
-    gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (capplet->sc_picker),
-				item->scolor->red,
-				item->scolor->green,
-				item->scolor->blue, 65535);
+    gtk_color_button_set_color (GTK_COLOR_BUTTON (capplet->pc_picker), item->pcolor);
+    gtk_color_button_set_color (GTK_COLOR_BUTTON (capplet->sc_picker), item->pcolor);
+
   } else if (strcmp (style, "none") != 0) {
     item = gnome_wp_add_image (capplet, imagepath);
     gnome_wp_capplet_scroll_to_item (capplet, item);
@@ -694,8 +691,14 @@ static void gnome_wp_file_changed (GConfClient * client, guint id,
   GtkTreeIter iter;
   GnomeWPItem * item;
   gchar * wpfile, * selected;
+  const gchar * uri;
+
+  uri = gconf_value_get_string (entry->value);
+  if (g_utf8_validate (uri, -1, NULL) && g_file_test (uri, G_FILE_TEST_EXISTS))
+    wpfile = g_strdup (uri);
+  else
+    wpfile = g_filename_from_utf8 (uri, -1, NULL, NULL, NULL);
 
-  wpfile = g_strdup (gconf_value_get_string (entry->value));
   item = g_hash_table_lookup (capplet->wphash, wpfile);
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (capplet->treeview));
@@ -746,6 +749,8 @@ static void gnome_wp_shading_changed (GConfClient * client, guint id,
   GnomeWPItem * item;
   gchar * wpfile;
 
+  gnome_wp_set_sensitivities (capplet);
+
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (capplet->treeview));
   if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
     gtk_tree_model_get (model, &iter, 2, &wpfile, -1);
@@ -770,10 +775,8 @@ static void gnome_wp_color1_changed (GConfClient * client, guint id,
 
   gdk_color_parse (colorhex, &color);
 
-  gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (capplet->pc_picker),
-			      color.red,
-			      color.green,
-			      color.blue, 65535);
+  gtk_color_button_set_color (GTK_COLOR_BUTTON (capplet->pc_picker), &color);
+
 
   gnome_wp_color_changed (capplet, FALSE);
 }
@@ -784,14 +787,13 @@ static void gnome_wp_color2_changed (GConfClient * client, guint id,
   GdkColor color;
   const gchar * colorhex;
 
+  gnome_wp_set_sensitivities (capplet);
+
   colorhex = gconf_value_get_string (entry->value);
 
   gdk_color_parse (colorhex, &color);
 
-  gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (capplet->sc_picker),
-			      color.red,
-			      color.green,
-			      color.blue, 65535);
+  gtk_color_button_set_color (GTK_COLOR_BUTTON (capplet->sc_picker), &color);
 
   gnome_wp_color_changed (capplet, FALSE);
 }
@@ -930,16 +932,16 @@ static void wallpaper_properties_init (poptContext ctx) {
   GdkCursor * cursor;
   const gchar ** args;
   GtkIconInfo * icon_info = NULL;
+  GtkFileFilter *filter;
 
   gtk_rc_parse_string ("style \"wp-tree-defaults\" {\n"
 		       "  GtkTreeView::horizontal-separator = 6\n"
 		       "} widget_class \"*TreeView*\""
-		       " style \"wp-tree-defaults\"\n\n"
+		       " style \"wp-tree-defaults\"\n"
 		       "style \"wp-dialog-defaults\" {\n"
-		       "  GtkDialog::action-area-border = 0\n"
-		       "  GtkDialog::content-area-border = 0\n"
-		       "} widget_class \"*GtkDialog*\""
-		       " style \"wp-dialog-defaults\"");
+		       "  GtkDialog::action-area-border = 12\n"
+		       "} widget_class \"*Dialog*\""
+		       " style \"wp-dialog-defaults\"\n");
 
   capplet = g_new0 (GnomeWPCapplet, 1);
 
@@ -1007,6 +1009,8 @@ static void wallpaper_properties_init (poptContext ctx) {
 
   gtk_widget_realize (capplet->window);
 
+  gtk_widget_ensure_style (capplet->window);
+  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (capplet->window)->vbox), 0);
   gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (capplet->window)->action_area), 12);
 
   /* Drag and Drop Support */
@@ -1155,7 +1159,7 @@ static void wallpaper_properties_init (poptContext ctx) {
 
   gtk_option_menu_set_menu (GTK_OPTION_MENU (capplet->wp_opts), menu);
 
-  g_signal_connect (G_OBJECT (menu), "deactivate",
+  g_signal_connect (G_OBJECT (capplet->wp_opts), "changed",
 		    G_CALLBACK (gnome_wp_scale_type_changed), capplet);
 
   add_button = glade_xml_get_widget (dialog,"add_button");
@@ -1221,15 +1225,15 @@ static void wallpaper_properties_init (poptContext ctx) {
   gtk_menu_append (GTK_MENU (menu), mitem);
 
   gtk_option_menu_set_menu (GTK_OPTION_MENU (capplet->color_opt), menu);
-  g_signal_connect (G_OBJECT (menu), "deactivate",
+  g_signal_connect (G_OBJECT (capplet->color_opt), "changed",
 		    G_CALLBACK (gnome_wp_shade_type_changed), capplet);
 
   capplet->pc_picker = glade_xml_get_widget (dialog,"pcpicker");
-  g_signal_connect (G_OBJECT (capplet->pc_picker), "color_set",
+  g_signal_connect (G_OBJECT (capplet->pc_picker), "color-set",
 		    G_CALLBACK (gnome_wp_scolor_changed), capplet);
 
   capplet->sc_picker = glade_xml_get_widget (dialog,"scpicker");
-  g_signal_connect (G_OBJECT (capplet->sc_picker), "color_set",
+  g_signal_connect (G_OBJECT (capplet->sc_picker), "color-set",
 		    G_CALLBACK (gnome_wp_scolor_changed), capplet);
   
   g_signal_connect (G_OBJECT (capplet->window), "response",
@@ -1259,6 +1263,8 @@ static void wallpaper_properties_init (poptContext ctx) {
   g_signal_connect (G_OBJECT (selection), "changed",
 		    G_CALLBACK (gnome_wp_props_wp_selected), capplet);
 
+  gnome_wp_set_sensitivities (capplet);
+
   /* Create the file chooser dialog stuff here */
   capplet->filesel = gtk_file_chooser_dialog_new_with_backend (_("Add Wallpaper"),
 							       GTK_WINDOW (capplet->window),
@@ -1275,6 +1281,16 @@ static void wallpaper_properties_init (poptContext ctx) {
   gtk_file_chooser_set_use_preview_label (GTK_FILE_CHOOSER (capplet->filesel),
 					  FALSE);
 
+  filter = gtk_file_filter_new ();
+  gtk_file_filter_add_pixbuf_formats (filter);
+  gtk_file_filter_set_name (filter, _("Images"));
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (capplet->filesel), filter);
+
+  filter = gtk_file_filter_new ();
+  gtk_file_filter_set_name (filter, _("All Files"));
+  gtk_file_filter_add_pattern (filter, "*");
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (capplet->filesel), filter);
+
   capplet->image = gtk_image_new ();
   gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (capplet->filesel),
 				       capplet->image);
@@ -1286,6 +1302,50 @@ static void wallpaper_properties_init (poptContext ctx) {
 		    G_CALLBACK (gnome_wp_update_preview), capplet);
 }
 
+static void gnome_wp_set_sensitivities (GnomeWPCapplet* capplet) {
+  GtkTreeIter iter;
+  GtkTreeModel * model;
+  GtkTreeSelection * selection;
+  GnomeWPItem * item;
+  gchar * wpfile;
+  gchar * filename = NULL;
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (capplet->treeview));
+  if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+    gtk_tree_model_get (model, &iter, 2, &wpfile, -1);
+    
+    item = g_hash_table_lookup (capplet->wphash, wpfile);
+    filename = item->filename;
+    g_free (wpfile);
+  }
+
+  if (!gconf_client_key_is_writable (capplet->client, WP_OPTIONS_KEY, NULL)
+      || (filename && !strcmp (filename, "(none)"))) 
+    gtk_widget_set_sensitive (capplet->wp_opts, FALSE);
+  else
+    gtk_widget_set_sensitive (capplet->wp_opts, TRUE);
+  
+  if (!gconf_client_key_is_writable (capplet->client, WP_SHADING_KEY, NULL))
+    gtk_widget_set_sensitive (capplet->color_opt, FALSE);
+  else
+    gtk_widget_set_sensitive (capplet->color_opt, TRUE);
+
+  if (!gconf_client_key_is_writable (capplet->client, WP_PCOLOR_KEY, NULL))
+    gtk_widget_set_sensitive (capplet->pc_picker, FALSE);
+  else
+    gtk_widget_set_sensitive (capplet->pc_picker, TRUE);
+
+  if (!gconf_client_key_is_writable (capplet->client, WP_SCOLOR_KEY, NULL))
+    gtk_widget_set_sensitive (capplet->sc_picker, FALSE);
+  else
+    gtk_widget_set_sensitive (capplet->sc_picker, TRUE);
+
+  if (!filename || !strcmp (filename, "(none)"))
+    gtk_widget_set_sensitive (capplet->rm_button, FALSE);
+  else
+    gtk_widget_set_sensitive (capplet->rm_button, TRUE);    
+}
+
 gint main (gint argc, gchar *argv[]) {
   GnomeProgram * program;
   GValue context = { 0 };
