@@ -56,7 +56,11 @@ GnomeWPItem * gnome_wp_item_new (const gchar * filename,
   if (item->fileinfo != NULL &&
       !strncmp (item->fileinfo->mime_type, "image/", strlen ("image/"))) {
     if (item->name == NULL) {
-      item->name = g_strdup (item->fileinfo->name);
+      if (g_utf8_validate (item->fileinfo->name, -1, NULL))
+	item->name = g_strdup (item->fileinfo->name);
+      else
+	item->name = g_filename_to_utf8 (item->fileinfo->name, -1, NULL,
+					 NULL, NULL);
     }
     item->options = gconf_client_get_string (client, WP_OPTIONS_KEY, NULL);
 
@@ -205,14 +209,17 @@ GdkPixbuf * gnome_wp_item_get_thumbnail (GnomeWPItem * item,
   } else if (!strcmp (item->filename, "(none)")) {
     return bgpixbuf;
   } else {
+    gchar * escaped_path;
+
+    escaped_path = gnome_vfs_escape_path_string (item->filename);
+
     pixbuf = gnome_thumbnail_factory_generate_thumbnail (thumbs,
-							 gnome_vfs_escape_path_string (item->filename),
+							 escaped_path,
 							 item->fileinfo->mime_type);
     gnome_thumbnail_factory_save_thumbnail (thumbs, pixbuf,
-					    gnome_vfs_escape_path_string (item->filename),
+					    escaped_path,
 					    item->fileinfo->mtime);
-    g_object_unref (pixbuf);
-    pixbuf = gdk_pixbuf_new_from_file (item->fileinfo->thumburi, NULL);
+    g_free (escaped_path);
   }
 
   if (pixbuf != NULL) {
