@@ -38,7 +38,7 @@ typedef struct
   gint data;
 } KeyListEntry;
 
-const KeyListEntry desktop_key_list[] =
+static const KeyListEntry desktop_key_list[] =
 {
   { "/apps/gnome_settings_daemon/keybindings/help", ALWAYS_VISIBLE, 0 },
   { "/apps/gnome_settings_daemon/keybindings/power", ALWAYS_VISIBLE, 0 },
@@ -59,7 +59,7 @@ const KeyListEntry desktop_key_list[] =
 #endif
   { NULL }
 };
-const KeyListEntry sounds_key_list[] =
+static const KeyListEntry sounds_key_list[] =
 {
   { "/apps/gnome_settings_daemon/keybindings/volume_mute", ALWAYS_VISIBLE, 0 },
   { "/apps/gnome_settings_daemon/keybindings/volume_down", ALWAYS_VISIBLE, 0 },
@@ -74,7 +74,7 @@ const KeyListEntry sounds_key_list[] =
   { NULL }
 };
 
-const KeyListEntry metacity_key_list[] =
+static const KeyListEntry metacity_key_list[] =
 {
   { "/apps/metacity/window_keybindings/activate_window_menu",      ALWAYS_VISIBLE,  0 },
   { "/apps/metacity/window_keybindings/toggle_fullscreen",         ALWAYS_VISIBLE,  0 },
@@ -391,6 +391,8 @@ clear_old_model (GladeXML  *dialog,
       g_object_unref (model);
     }
 
+  g_object_unref (client);
+
   model = (GtkTreeModel *) gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
   
   sort_model = gtk_tree_model_sort_new_with_model (model);
@@ -425,18 +427,21 @@ static gboolean
 should_show_key (const KeyListEntry *entry)
 {
   gint workspaces;
-  
+  GConfClient *client;
+ 
   switch (entry->visibility) {
   case ALWAYS_VISIBLE:
     return TRUE;
   case N_WORKSPACES_GT:
-    workspaces = gconf_client_get_int (gconf_client_get_default (),
+    client = gconf_client_get_default();
+    workspaces = gconf_client_get_int (client,
 				       "/apps/metacity/general/num_workspaces", NULL);
+    g_object_unref (client);
+
     if (workspaces > entry->data)
       return TRUE;
     else
       return FALSE;
-    break;
   }
 
   return FALSE;
@@ -544,6 +549,8 @@ append_keys_to_tree (GladeXML           *dialog,
       gconf_schema_free (schema);
     }
 
+  g_object_unref (client);
+
   if (i == 0)
       gtk_widget_hide (WID ("shortcuts_vbox"));
   else
@@ -884,6 +891,7 @@ setup_dialog (GladeXML *dialog)
 			   "/apps/metacity/general/num_workspaces",
 			   (GConfClientNotifyFunc) &key_entry_controlling_key_changed,
 			   dialog, NULL, NULL);
+  g_object_unref (client);
 
   /* set up the dialog */
   reload_key_entries (wm_common_get_current_window_manager(), dialog);
