@@ -268,7 +268,7 @@ main (int argc, char **argv)
 		setup_dialog (dialog, changeset);
 
 		dialog_win = gtk_dialog_new_with_buttons
-			(_("Sound preferences"), NULL, GTK_DIALOG_NO_SEPARATOR,
+			(_("Sound Preferences"), NULL, GTK_DIALOG_NO_SEPARATOR,
 			 GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 			 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			 NULL);
@@ -285,6 +285,7 @@ main (int argc, char **argv)
 		gconf_change_set_unref (changeset);
 	}
 	
+	g_object_unref (client);
 	g_object_unref (dialog);
 	return 0;
 }
