@@ -138,6 +138,10 @@ static TranslationEntry translations [] = {
       GCONF_VALUE_STRING,	translate_string_string },
   { "/desktop/gnome/peripherals/mouse/cursor_size",	"Gtk/CursorThemeSize",
       GCONF_VALUE_INT,		translate_int_int },
+  { "/desktop/gnome/interface/show_input_method_menu",  "Gtk/ShowInputMethodMenu",
+      GCONF_VALUE_BOOL,		translate_bool_int },
+  { "/desktop/gnome/interface/show_unicode_menu",  "Gtk/ShowUnicodeMenu",
+      GCONF_VALUE_BOOL,		translate_bool_int },
 };
 
 static TranslationEntry*
@@ -164,32 +168,23 @@ type_to_string (GConfValueType type)
     {
     case GCONF_VALUE_INT:
       return "int";
-      break;
     case GCONF_VALUE_STRING:
       return "string";
-      break;
     case GCONF_VALUE_FLOAT:
       return "float";
-      break;
     case GCONF_VALUE_BOOL:
       return "bool";
-      break;
     case GCONF_VALUE_SCHEMA:
       return "schema";
-      break;
     case GCONF_VALUE_LIST:
       return "list";
-      break;
     case GCONF_VALUE_PAIR:
       return "pair";
-      break;
     case GCONF_VALUE_INVALID:
       return "*invalid*";
-      break;
     default:
       g_assert_not_reached();
       return NULL; /* for warnings */
-      break;
     }
 }
 
@@ -255,10 +250,9 @@ xft_callback (GConfEntry *entry)
   GConfClient *client;
   int i;
 
-  client = gconf_client_get_default ();
+  client = gnome_settings_daemon_get_conf_client ();
 
   gnome_settings_update_xft (client);
-  g_object_unref (client);
 
   for (i = 0; managers [i]; i++)  
     xsettings_manager_notify (managers [i]);
@@ -383,7 +377,7 @@ gnome_xft_settings_set_xsettings (GnomeXftSettings *settings)
 static void
 gnome_xft_settings_set_xresources (GnomeXftSettings *settings)
 {
-  char *add[] = { "xrdb", "-merge", NULL };
+  char *add[] = { "xrdb", "-nocpp", "-merge", NULL };
   GString *add_string = g_string_new (NULL);
   char *old_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 
